*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2011 Micron Technology, Inc. All rights reserved.
*
************** 128egx4, 64Megx8, 32Megx16 DDR SDRAM ***********************
***************Example HSPICE setup for CLK/CLK# inputs***********************
****
***********************************************************
****             ___                                      *
****    CLK_OUT-/  +|-CLKPAD----\/\/\/--@@@@-----IN_PKG   *
****           {   -|-CLKPAD_--| R_pkg  L_pkg |           *
****   CLK_OUT_-\___|-RCVREN   |             ===C_pkg     *
****                           |              |           *
****                           |             GND          *
****                           |                          *
****                           -\/\/\/--@@@@-----INN_PKG  *
****                            Rn_pkg Ln_pkg |           *
****                                         ===Cn_pkg    *
****                                          |           *
****                                         GND          *
***********************************************************
****
**** This netlist is for the x4, x8, x16 512Mb DDRI SDRAM 
**** The RCVREN signal is output enable.
**** The Input signal is PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.
****
**** The .LIB statement selects the following simulation corners:
****   TYP_333  - 266/333 Mbps data rate, Typ N,  Typ P,  Typical die capacitance
****   SLOW_333 - 266/333 Mbps data rate, Slow N, Slow P, Maximum die capacitance
****   FAST_333 - 266/333 Mbps data rate, Fast N, Fast P, Minimum die capacitance
****
****   TYP_400  - 400 Mbps data rate, Typ N,  Typ P,  Typical die capacitance
****   SLOW_400 - 400Mbps data rate, Slow N, Slow P, Maximum die capacitance
****   FAST_400 - 400 Mbps data rate, Fast N, Fast P, Minimum die capacitance
****
****
**** To run this simulation, the files "t67a_model.cnr" and "t67a_clkbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Commercial temperature settings are: Typical 50C, Slow 85C, Fast 0C
**** Industrial temperature settings are: Typical 50C, Slow 100C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 120C, Fast -40C
***********************************************************

.OPTIONS POST
.OPTIONS METHOD=GEAR
.OPTIONS GSHUNT=1E-12
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns '12*per' start=delay

.LIB "t67a_model.cnr" TYP_333
*.LIB "t67a_model.cnr" TYP_400


**** Temperature is for typical case (CT=50C, IT=50C, AT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
******Voltages for DDR1-266 and DDR1-333
.PARAM  vcc_typ   = 2.500V
.PARAM  vcc_min   = 2.300V
.PARAM  vcc_max   = 2.700V

******Voltages for DDR1-400 
*.PARAM  vcc_typ   = 2.600V
*.PARAM  vcc_min   = 2.500V
*.PARAM  vcc_max   = 2.700V

******vccr internal regulated power supply
.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  gnd       = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc       = vcc_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvcc    vcc   0  DC = vcc
Vvccr   vccr  0  DC = vccr
Vvss    vss   0  DC = vss

***********************************************************
**** INPUT SIGNAL
***********************************************************
**** Input Stimulus Parameters
*.PARAM datarate = 266.67E6
.PARAM datarate = 333.33E6
*.PARAM datarate = 400.00E6


.PARAM pulsewidth = '1/datarate - dataslew'
.PARAM per = '2*(1/datarate)'
.PARAM delay = 1ns
.PARAM dataslew = 300p

**** Vin/Vin_ toggle the CLK/CLK# at the clock rate specified above
Vin   PKG_IN  0  PULSE vss vcc delay dataslew dataslew pulsewidth per
Vin_  PKG_IN_ 0  PULSE vcc vss delay dataslew dataslew pulsewidth per

***********************************************************
**** RECEIVER ENABLE SIGNAL
***********************************************************
**** Active high for receiver output
Ven  RCVR_EN  0  DC = vccr

***********************************************************
**** TOP CELL:  t67a_clkbuff
***********************************************************
xi0 RCVR_OUT PAD PAD_ RCVR_EN vss vccr vcc t67a_clkbuff

***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad  PAD  PKG_IN  pkg  r=163.57m l=1.86nH c=0.32pF
x_pkg_pad_ PAD_ PKG_IN_ pkg  r=161.82m l=1.81nH c=0.31pF

.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
.ALTER

.TITLE Weak

.PARAM  vcc         = vcc_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (CT=85C, IT=100C, AT=120C)
.TEMP 85

.LIB "t67a_model.cnr" SLOW_333
*.LIB "t67a_model.cnr" SLOW_400

***********************************************************
.ALTER

.TITLE Strong

.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (CT=0C, IT=-40C, AT=-40C)
.TEMP 0

.LIB "t67a_model.cnr" FAST_333
*.LIB "t67a_model.cnr" FAST_400


***********************************************************
.ALTER

.TITLE Disable Receiver

Ven   rcvr_en   0  DC = vss

***********************************************************
.END
