*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2011 Micron Technology, Inc. All rights reserved.
*
************** 128egx4, 64Megx8, 32Megx16 DDR SDRAM **************************
*******Example HSPICE setup for all input circuits except CLK/CLK# & DM*******
****
***********************************************************
****             ___                                      *
****            /  +|-PAD----\/\/\/--@@@@--------PKG_IN   *
**** RCVR_OUT--{   -|-VREF   R_pkg  L_pkg     |           *
****            \___|-RCVREN                 ===C_pkg     *
****                                          |           *
****                                         GND          *
***********************************************************
****
**** This netlist is for the x4, x8, x16 512Mb DDRI SDRAM 
**** The RCVREN signal is output enable.
**** The Input signal is PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.
****
**** The .LIB statement selects the following simulation corners:
****   TYP_333  - 266/333 Mbps data rate, Typ N,  Typ P,  Typical die capacitance
****   SLOW_333 - 266/333 Mbps data rate, Slow N, Slow P, Maximum die capacitance
****   FAST_333 - 266/333 Mbps data rate, Fast N, Fast P, Minimum die capacitance
****
****   TYP_400  - 400 Mbps data rate, Typ N,  Typ P,  Typical die capacitance
****   SLOW_400 - 400 Mbps data rate, Slow N, Slow P, Maximum die capacitance
****   FAST_400 - 400 Mbps data rate, Fast N, Fast P, Minimum die capacitance
****
****
**** To run this simulation, the files "t67a_model.cnr" and "t67a_inbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Commercial temperature settings are: Typical 50C, Slow 85C, Fast 0C
**** Industrial temperature settings are: Typical 50C, Slow 100C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 120C, Fast -40C
***********************************************************

.OPTIONS POST
.OPTIONS METHOD=GEAR
.OPTIONS GSHUNT=1E-12
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns '6*per' start=delay 

.LIB "t67a_model.cnr" TYP_333
*.LIB "t67a_model.cnr" TYP_400


.TITLE Nominal Full Drive

**** Temperature is for typical case (CT=50C, IT=50C, AT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
******Voltages for DDR1-266 and DDR1-333
.PARAM  vcc_typ   = 2.500V
.PARAM  vcc_min   = 2.300V
.PARAM  vcc_max   = 2.700V

******Voltages for DDR1-400
*.PARAM  vcc_typ   = 2.600V
*.PARAM  vcc_min   = 2.500V
*.PARAM  vcc_max   = 2.700V

******vccr internal regulated power supply
.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  gnd       = 0.000V
.PARAM  vssq      = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc       = vcc_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvcc    vcc  0   DC = vcc
Vvccr   vccr 0   DC = vccr 
Vvssq   vssq 0   DC = vssq
Vvref   vref 0   DC = '0.5*vcc'
Vvss    vss  0   DC = vss
Vvtt    vtt  0   DC = '0.5*vcc'

***********************************************************
**** INPUT SIGNAL  
***********************************************************
**** Input Stimulus Parameters
*.PARAM datarate = 266.67E6
.PARAM datarate = 333.33E6
*.PARAM datarate = 400.00E6


.PARAM input_rate = 'datarate/2'
.PARAM pulsewidth = '1/input_rate - dataslew'
.PARAM per = '2*(1/input_rate)'
.PARAM delay = 1ns
.PARAM dataslew = 400p

**** Vin toggles the INPUT at the input rate specified above (1/2 datarate)
Vin   PKG_IN  0  PULSE vss vcc delay dataslew dataslew pulsewidth per

***********************************************************
**** RECEIVER ENABLE SIGNAL  
***********************************************************
**** Active high for receiver output
Ven    rcvr_en  0  DC = vccr

***********************************************************
**** TOP CELL:  t67a_inbuff
***********************************************************
xi0 RCVR_OUT PAD RCVR_EN VREF vss vccr vcc t67a_inbuff
***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad PAD PKG_IN pkg  r=148.22m l=1.59nH c=0.27pF 

.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
.ALTER

.TITLE Weak

.PARAM  vcc         = vcc_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (CT=85C, IT=100C, AT=120C)
.TEMP 85

.LIB "t67a_model.cnr" SLOW_333
*.LIB "t67a_model.cnr" SLOW_400


***********************************************************
.ALTER

.TITLE Strong

.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (CT=0C, IT=-40C, AT=-40C)
.TEMP 0

.LIB "t67a_model.cnr" FAST_333
*.LIB "t67a_model.cnr" FAST_400
***********************************************************
.ALTER

.TITLE Disable Receiver

Ven   rcvr_en   0  DC = vss

***********************************************************
.END
